
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\t/\x00\x00PYARMOR\x00\x00\x03\x06\x003\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xc9.\x00\x00\x00\x00\x00\x00\xc0\xe6\xf1P\x0c0\xff\x88\xc7\n%\x9ffs%\xa2\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xed\x90\x02V\xfcC'
        b'\x15Z,F\xdc\xcc~\xc2=\x83Y/AW\xd2EwO\xafU\xa2\xcb2\xa3qfIl\xf7\xd6X\xd3\x18\xe0\xc8\x9fw/\xa2\xa9[\xb2_r\xda\x8f-\x08\xa1\xb9\xa1\xb1b\x84q\x02\xce\x022\x96\x94\x0fl\xc7'
        b"\x9e\xc4\x19\xef\x12\xcf\xc4'+\xb4\xaa\x8c\xc9\xc5%\x8b:\x9e\x85\xce\xc8\x15m\xd8\x1eb\x0cM\x81e\xc9\xfc\xb5\xe4=f\x03O\xf4\x1e\xb0I<[g/\xaf\xfdV^n's\xeb\x16s\xd6+\xfc\x1br\xc2i\xbe"
        b'\xed\xa4G+\x11\x81\x1b\xbb(\x86\xb7~)\x86x\x9c\xb4\x9fe\x16y\xa4\xff\rn*&\xd8\xd1\xb8G\x9f\'y\xd5\xf0\xe2\xf9 \xa0\xf8M\xebO\xe2\x1d<\t\xe8\xcb\xf6\xe6\xa1\x00\xc8\xcd-"\xec8t\x8b\xe1\x9d'
        b'K\x13\xa5\xf3\xfa\xb9D\x11\xfe\xf8&\xb7\x81E\xc1\xd2\x02\x05\x1c\xe4\xe7\xe0\xb9\x10\xd9\xcf\xae\xa7\x9a\xd8\xd2\x1b\n(\x05\x8a\xb2UCO\x956\xadM\x93\x040=R\xb7\x0e\r:\x8e\x9e\x18\xb9\xe1j\x89\t\x8f0w'
        b']`\x11\x89\xef\x1fuj7$\xb2C!3\xa0\x80\xf3\xec\xd7-\x91\x92\xb0\xb7\xeb\x1f|!1\xc3\xb5\x1aA\xec3-\x1e\x1b\x9aWm5&\x86\xf5\x89\xcd\xc0\xb6\xf8\x04\x93\xb6>\xd3\xb6\xf9\x8b\xe2\xb5\x1bB\xc2\xb7'
        b'\x8b\xaff;\x8b\xbf\xdc\xc4\rp=\xa1\xc9\xcap\xb3\x1f"\x04\x1a\'\xfa\xcft\xb3*\xaa\xad,\xec_\xb7\x0e\x08\xea\x8a7q-\xb3Na_D>c\xc1z\xc8\x1b:w2:0\x84L\x04\xca\x93"\xef8\xf0'
        b'\xbf\x91:"\x89w\xcdLY\x1d^k\xd2\xf0,\xf0\x0f\x1b\x02\xf4\x16\xed\xcbWJ|)3\xa6y8\xaa\x1f\xb8`&\\*\xa2D\x9c7$\xdf\xf2\x04\xfaE\xf2\xfe]\xdc\xd3\xfb\xba\xca~\xb3\xa0\x04g\x16q\xcf'
        b'\x99g\x91\x84-O\\e\x1a\xb6\xe0n\xae\x8e\x8f\x897^\xec?\xe4\x10`y\xd6\x13%#@5k\xa1\xbd\x88!\xcd\x93(\x90\xb6^\xc9\xdf\xd1\xb7\x157H\xb8\x9eS\x1c\x07\xb6\xc9\xe2\x16@8\x0c\xc5\x8f\x07-'
        b'\x15MT\xe0\t\x85\x1f\x92\x94\xff\x8a\xd1Z\x87\xf0F\x0e[,pp\n\x8fu\xa1I\xa4mPs\x00\xdd\x8d\xdd\xd4\x11\x99Q*q\x9dX\x99md\xa4le*\xe6\xef\x12aL:-\x11L\xb3(\xfa\x1b\x11;'
        b"b0H+\x9b_\xe8\xaf\n\xe6\xc8\xaaX\xee\xbc\x08\xd5\x161\xa6\xd4'\xdaq=\x17\xfb\xcb%\x93\xdc~:h@\xeeR\xc7\xdcrf\xf3\xe9\x12\xcd\x08\n\xea\xe2\xff\xf3y\xc1\xcb[\x0e\xf3\xb5\xa5/\x06\xe5X\x93"
        b'\xe40/\x0f\x03K\xc7\xca\xef~I\x83\xd44\x001\x07\xb3\x14\x14Ny\x9d\xb8*\xd0\xa7\x84\x01\xb8\xf4\xd3\xcb\xeeX\x93\xdc\xba\x86\xbe\xb6\x7f\xdc\xa5.\xa7@h\x1b\x8b\xbc%sj&\xd2\xcd>\xc4\xe8\n0\xfe-'
        b'\x1bat\xf66ifX\x92\x7f:.=\xc1e\xc2\xbe\x1c\xac\xb0\x07\xf3\x89q\xf18\x0f\x0ft\x969\x1d\r:\xf2\xc3\xbf\xee\xf2\x18\x17!\x10;,\xa2\x92^ -\xeb\x0ek\x8a\x17\x88R\x9d\xc2\xf3i{\xa5\xe9'
        b'j%bB\xa0\x9a\x0b3\xda!\xbbyx\xab"&!v\r7\x89\xb6\x90V\xbe]\xa3P\xe9S\x03\x8bys\xf9\xebXjni\xd3ya\xc1\xc4fB\xfe1\xf6\xb2\x17\x89\xf5\xc4\xb4\x14\t\x11\xc7\xe7\xdf\xa4\xdd'
        b'6\xc6\xa8\xac\xb3\xe7Y\xece\x9c\xef~\xb0\x16>\x90d\xcaw\x94_\xb5\xb2\xee\xa1\xf1\xe86J:P\x9d\xca\x8b\xdc$\xca5D5\xf0\xeb%V\xa9QP\x80F\x98\x90LM\xe2\xae\x82Y\x13\x9bE"s\x9a\xa9'
        b'\xb2K\xcc\xec\xf2G\x17\tV\x83\x8f\xb0If\xbcY\xd7J\x12Mf!\xef\xd9\xe9yu\xaa\x01\x17\xe1\x1eop\x16\x84\x9d\xe4fx`\x90f\xe0\x8d\x9c\x8a\xea\xf5\xf9+d\x93\x8a\x92\xb5\x14\xafx\xfe\x1c\xd3\xf9\x86'
        b']P\xbbg\x1d\x8ep\xf3\xaeF\xff"vEJ\xb4\x92\x11\x08\x04\xbe\xb5\xfa\xd7L\xcc\xbfW\x81K\x0eyM\xe8L(\xc2&c\xe4\xdb1\xfdA\x1bR\xa7\xcf\x87G\x9eP\xd5V\xa5\x86\xb5\xf2\xd5\n=G\xcfz'
        b'\xe1\xd3\xe6\xf7|\x90/\x9e\xc8__\xed\xac\x8b\xdc\xd9^\xfe\x00"\xb7;\xa1\x0c\xfa8A\xae\xf8\xd4\xc7\xbc\tm\x8e\x04\x1a\x0c^Q)\xa9&\xb32\x1a\x88\x7fv\x91\x15\x02\xbd\x84\x88w\xb7\xa9f$\xbc\xfa\xd0\xcc'
        b'\xc6\x83|\xf6\x94\x07\xcd}\xbe\xdd0\xc3\x112\x1bU\xa1mZ\xa9\xff\xbb\x13y\xd9\xa5;$\x87\xea\xad\xd63\xb4\x08\xc7gs\x9a@\xae\x9b.\xbd\xa5\x00\xe7=G\xb2\x94\xee\x99\x95\xb3\xcf\x0e\xadSc\xa9\x9c\xc1\xcc'
        b"'\xbeD\x95\xebT\x14\x98\xfa\x9d\xe8#\x9a@9(G9\xe2%lT,oU\xd6\xf2\xf6 g\xd4ds8pQ\x87\x82U\xea\xc73\xacN\xd4\xb0\xa9GtdY\xd2\x15\xe5\x18\xb6\xd85W~\x7f\xdfp\x02"
        b"\xf6T\xf1\xca\x99\xba\xfa+\xf2\xc0H\xd1\xeb\xd7E\x0bx\x8e\xe4Z\xa1\x8d:,\xc7\x93\x9a\xbd@\xe7cJ\xd3a\xd0)\xee's\xe0\xba\x0fwg[Z\xe2\x99\xd5r\x18\xf8\x16\x85\xfb\xe8i/\xfc\xa3<\xf3\xbfO"
        b'\x8bu\xef\xafOWh\xbf\xcc\x036\xa6\x8aA%$\x1d\xf7\xc6\xaa\xdb\x97\x9b:\xf6M\xba DuD\xd2\x18\xd9\xca\xe7\r\xfd\xcb\t\xa4jB\xd7\xcdz\xc6F\r\xd5\xdb?\x05u?<>\x96\xc7\xcb2\xbd\x0c\xf9'
        b']Nv\xdc\xbcY1V\xcfC\x979\x17[\xee\xeb\x81/\x9d\xe3pamVk\x0c_O\xa8=i\xba\xa0,\xb6\xf1l\x11nu\x9f=\x01\x18\xefK\x1a\xbe\x1f\xf4\xfeO\x9c\x1b\xbei]]Z\xf3[\xff\xd1\xbf'
        b'Q\x90\xca!\xcc\xaf)\xb0V\\:\xb8\xc7\xaaY\xaa\xa4\xb1.\xf8\xd7\x13\xd0\xb6w\xf0\xa3Mrw\xbc\x0e\x8e\xfc\xd5\xa46\x9f\xe6\xe69\xdaZKK\x14/\xde\xd5\x086\x96\x94\xaa\x89\xd6|%\xf5\xb6\x14&\x1fM'
        b'\xf5\xc7\x9a8\xe7\x1d\x01\xf3.\x8d\x99?s+AC\xe9M;\x11<nj\x99eXM:\xec/\xd82\x06\xd89\x85\xf8\xdbj\xb3\x0fjm\xfc\xca\xb3\xd4\x81\ra\xb6}\x06\xb4\xf7\xe5\x17q7\xf9$mh\x7f'
        b'\x087\xf5k\xe8\xb8\xeeH\xae\x0f\xd14*H\x92p\x7f\xd2K\xfb\xe3\x18\xa3GnT\x93\xf1Z\xd0r\xa9\xb5\xd7_\xfe\t\xec\x85g)\xd2X7\xe9#\x809\x0b\xdf\xbdS\x15\xf5\x98}\x9b\xef}\x14Y\xf7\x15\xda'
        b'\xa3\xe8\x0e#\xb8\x87\xa3\xda\xdf\x94\xfb\x92\x1d\x8c\x87\xd9\x7f\xff\x9a<\x0b\tM,\x86g"0\x16(\xca\xebm\xd2\xa4R\x1b\xc1\xce\x8aA\xc7p\xa4)\x1f,(\xa9S]j\xfep\xfb]\xeb\x12\xc1\x83\xd6\xafi\xcc'
        b"\xbfQ\xba}9\xa3\x8f?':\x9br\xff\xb7#\x1d\xb78\x87T=\x10\xdb\x86\x95\xd8\x03\x9b\xac6\xd3_\xc8u\xd1\x9d\xc4I\x08\xea:\x1e\xe3\xb7\xe8Z\x95\xe6\x9e\x0f\n\x00\xff\xa1\xa4A_\xd7\x9d\x1c\x18d\xafY"
        b"\x17t#\x1fc\x97\xd5&\n\xa5\xc4\xa2\x08L@)\xa2\xa2*+\x90\x10}\xabU|\xee\xe0\xfeJ\xf3&(=:\xe1[kG\x85\xa8\x80\x9e->\xd4'\xc2e\xc2\xbfJZi\xea_\xcag\xf0\xab\xdf\xf2KE"
        b'\xbcE\xcb\xb3\xb75\xbe\xb5\x8f\xb9\xde\x16O\xe7\x017wTzb\xc2$\x97\xa2\xad$\xd4i\xbb\xd7t\xae?d\x82W,Ux\x86r\xb9\xd9\x81)fh4!\xe8uI;\xb3\x85\x880\x96\x93\xa4\x06\xaa\xd4\x18'
        b'\xd6\xe1\xf1__n\xf6"\x8c\x993\x7f\x86\\z\xae\x8f\xb0\xfb\x87x\n\xcbh\x11"\x08\x8bp5B\x1da\x84\x8cz\xee+\x7f\xfe\x9awH`\xad\xa6-^]\x14\xcc\xd4-\x97\x0eX\xb8\x84\xb8\xb5\x01=\x9c\xe0'
        b'0%\xe6w\xaf\xc5\xeb\x85\xc4\\N|t\xd4\xb8z\x7f\xb1\xc5M\xc3\xe05\x89\xbe\xa9\xb0\x12\x14\xacE\x18\x88\xda#<.9\x82)r\xe7\x9c\xf11X\xed\x93\x99y\xb3\xed\xb9a/\x88\xcdN~\xf3\xeb\xb6\xc2#'
        b"\x9d\x10\x7fO`\x8c\x88\x01o\xeb\x7f\xbd.\xe4WO\xc3@\xb2\xa9lS\xf0QI\x16\x9a\xc3\xd8uf_\xb5P\xbeDz\xfb\x96I\xde\xcc1Y?Z\x04s\xdc\xa2'a\xe2\x9f\xfa\xda*\x8e\xf3B\x7fl.J"
        b'N\xcb\xc2\x86B\x88\xb9\xce\xa46\xd8\xf5M\xfa\xca\xf3\xb0\xbf.t\xec~\xa1\xde\x01\x13H\x19\xec\xdf\xde\xa7\x0f\x05\x05\xcb\xcbG\xb6\x9a.\x0e\xda@\x8a\xa0\x12a`\x8c\x7f\xf3\x7fyu%\x0f\x92qz\xbf\xb6]\xb1'
        b'> d\xc1\xfd\xb5\x92\xe3;F\xe1\xd6\xecm\x18\xb2\xea\x06u\xdde\xde5$\xb3\x02\xcc\xca\x02\x8d2\x81A\x9f+\x8dx\x8a\x83\xac\xdf\xccY\t\xae\xe6\xdbd\xc8\xb1\x11d\xa9\x183\x1d\t9\x11\xa5i\x1c\x12\t'
        b'\x8a\xdc\xe2h)\x01{\x84\x12\xf9K\xbb\xf1\xc3\xb2\x9b/\x15\x0c\xd5Zr\xf6yIdA83.\xe4<\x8ek\xc4\xab\x0f\xa8\x83/Zl\xba\n\xe6\xf5\xad\xd4I\x07\xce\x02\xe9d\xdbM8\xd6\xfc\xdc\x87\xf0\xce\x88'
        b'\xdc\xa8\x14\x95~\x18j\xb4\x13\xb1\x9a\xbe6\xb3^\xb1Sjm\xec\xe3M!\xa1\x86\xfd\x00\xb9`\xfb@\xce\x1d\x15\x1d\xd1\xd4\\H\x18%\xc1\xbf\xaaI*x>K\xfe\xd3\xb0\xd0_\xfe\x87\xb1\x12?\x1fP\xe2\xd3]'
        b"\xa1\x0f\x86\xa2\x82\xc8\xc3'\x8c\x82\xd80N\xcc\xc9/dx\xbcD@\xfc\x15\x14J\x18\xae%}n\x07]\xc8\x85f$\xcc\n\x82\xb8&L\xd1F\xb5\x8d\xbf\xac\x8a\xa6\xe6\xbdX\x02r\x9a\x0f\xea\xff\x10\xeb\xcb\xd9\xbb"
        b'{\xa6\x1c\xd2\xbck\xd7\xda\xa1q\xea\xaa\\#:\x88\xc6\xef\x8c\xe8-?\xafZW\xad\x87_\xcc\xfd\xb0\x97\xcf\xe6}\x9b+\t.\x82\xf1\xa8\x11\xf1\xe9\x1a\xdeJ\xac\xa6\xac\t\x17\xd1\xba\x96\x02-\xbc"\xd5g\xe7S'
        b')C\x97\xac\xde\xf5\xd7 \x99@\xeb\x8bQ\xf9\\`R\t\xf4\xbb\xdd\xca\xbd\xcd\xb1\\k\xb0\xa4uv2\xfc\x82\x85-\x03F\xf5\xec\xbd\tsL:\xd6\xce\xf4\x0e\x8b\x1aa\x0f\\\xab\xa3j\xf0\x04\xa2^\x85\xaf\xe6'
        b'q0\xae\x8e\xfc\xa2\xd9b\xc3gJ\x97\xf70\x0b\xb6!W\xffF\x1bk\t\xe2\x12\xa2\x05\x19\xc6\xa2D\x1bW\xc4\xc2q\x96\xb6\xc6=\xbb\xb6l\xdd\x1d\xac\r\xe6xd\xc4M\x97/\x8e\xb3[\x1e\x9d\xf6\xed\xa2w\xc4'
        b'\xfd}K\xb7\x01\xaes\x86s\n\xfeq\x9b\x10\xc2{[\xda\x04=2F*\x9a(=S\x93\xf3\xd5_\xcb\xfb\xc6\xe4\xdd\x90\xfc\x02\x9b\xac\xa3h\xd6\x1b\xa76j\xc9\x13W\xf1\xd4\x8d\x15\xabs\xe0\xea\xa1\xc4[\xd96'
        b'?\x94|\xca\xc3\xe9\xf7\x19\xa9\xf6\xdf\x95\x8a\x97BaM?\xa2T\xb5\x81\x87#\xef:\xef,\t9\x99\xca^\xc8\x08\x02\x10\xfc\x12A\xf0\xd3\x9e\x05p>\xf4n\x84\xd0\x98\x9d\x08\xb9R\xd6\xa7P\x14w\x14\xcb\xe8\x10'
        b']\x1e\xc6L\n\x84b\xd4I\xee"\x90\xd2\x8c\xae\x08\xfcO\xb6\xe2\x8ci\xd7\xd5\xde\xc6T\xdd\xab\x90\x05\xc3F\x02\x03D\xf0&\x17\xe2o\xfa\xa5\x1f\x91#S\xda\x11\x8e\x96u\xff\x05\x01\xd5\x84{k!\x8cb\x08('
        b'T\xea\x04/\x03\x07\xa8\x1fiS\x9b bFX\xdb\x97\x16\x98\x0f\xa9\xc5 ]h\x1c6\xb8\xaa4\x8f\xfe7\xfdz}\xdb\x01\x97\x00c\xeb\xa9\xb8\xb4G\xa1\xaa_\xf0\x94\xa15z+\xd2\xddd\x1d\x15\x9b\xf3T\xa4'
        b'\xa4\xe9\xc3\x9e\xad\'R\x00\x9b\xb4\x93\xe8\xbf6\xc5^\xc9\xc5\xe4B\xdbM("\x8d|\xf0\xc9\xb3\x90\x05\xe7\x95\xef\n-\xe5{\x13\xec\xe6\x0f\xa0 \xa4\xdc\xf1\xdd:)\x1e\xa7m\x11\xa3=\xfaW\x00\xac<\xbf\xcbh'
        b'8\xaa\xf6\x9e\xacG\x9c\xba/\xde4M\xdf6\x7f\xc2\x01\x18\xf6{*\x04\xe0\xbaU\x9ep\x80.\xb9\xee/\x13\xa0l\xe5"O\x19y}\xcb.\xcf\xb1\xd6\x82\xd1r\x04\xad\\\xc9\x85\xe1R7\xa5\xcb\x8ez\xd2Qa'
        b'\x18\xbeoIT$\x16\x9b\to\x03Q\x90`\x16u\xbaT\xe8mF\x99\x89K\x12?@\x9a\xbb.\xf5y\x97~&@\xb5\xa4\xcd\x15Nj4sJ\xd8\xcaV\xc73\xa8\xda\x99\x8b\xb8@\xb7j\x91\x8aj\xef\x1aj'
        b'\xa3\xc5\x1fG\xf3\x08m3\xc5"\xe9b\n\x80\x9a\xf3bmzo\x1cF\xe4\xdc\x80t\x19\x90\x84\xa3\xa3\x8f\x14\xdae\x04\xf1F"\xb9}.)\xe7O\x0cy\xe3\xca\x92|\xed\xce\x8f\xa27{D\x80>\xeadH\x92'
        b'\x8f\xbf\xa2\xe0\x9d53\x94\xe9f\xd1\xd4\xa6\x01_3j\xd6\xeb\xf1\x85\x7f^\xd8y\x1f\xa2$\xe2\xa9\x1c\xc6\xf2Y\xd7/\x9f\xb7Uxi\xba\x7fO\xac2\x90\xb4\xf3Dl\xf2\x0c\x9c>\x03\xef\x18e\xdb\xa0\xea\xfe\x87'
        b'\x80S\xe6i\xb242\x92\xfe\x17a]HBoXn\xf3\x1b\xf6\xd1f\xf3<\t\xb9@\x045\x01w\x97(\xd3\x9d\x93\xce\xef\xf8}\xd65|{\xd2#\x1b\x10G0\xb3b\xf5\x94\x81\x8c\xfdn\tP\xd7\x05\xa3\xa1'
        b'\xf2~9-\xe9\xa8^\x88\xba\xe0\xde\x03kVF\x1a\xeb\x18#Y\xba\xb6\x07\x1a{-Y\x08\x97\x7f\xe7\x89\xe1S\x1f\x9a\xbe\x97f\xa6\xdd^\x1a\xc1\x08\x98d\xbc\x13\xf3\xd1\x96+t\x14\t\x11\x96\xdb\x1f\x14K\xaaV'
        b'\xc1?\x10\x1b]\x0bMmHR(8\xa3N\x08U\xd6\x94\x02\x7fg\xdab*e?\xfca\xad\xb1\x7fP\xf5\xe1W\xe3\xf6p\xbb\xaeKp_w&\xb7\x12\x82CF\xc7\xe7c\xa9\xb1\x7f)3\xb3\xb4\x89\x01\xd9z'
        b'\xcf\xc4\x10\xc2\x1f\xeaO@x\x07\xbcYG\xa7/\xe2\xf2\xae\xeb\x07ug5\r\x01aH\xda#\x1e\xcb\xca\xf7x\x98\xe0\x8d\x15iu\x10W\x8d\xb7!\x15|\xad\xb7K\xac\xbd6dE\xdd\x8d\xcb\xa5\x0b\xea\xca\x98N'
        b"\xfd\xdd\xae\xf4'\x96G\xba\xa8\xa9\x9c\xab\xe6\xd229*\xa7\x7fY\xd4\xc6pV\xba\xb4\x19S\xd1>\x9f(\xc3g\x11\x7f\xacU\x90e\x08\xc2Y\x8fF\n^_\xb4\xbe\x90\x98\xd9\xea\xe7.~\x97\x13\xfcG\xaf\xa7\xd8"
        b'D\xbbx\x11\x9e\xe6U\xcbR\x0e\xeeo\xbf?5\x07 \xcaY#\x1d\xfe\xe8\x05\xf5B\x89\xe1z\x05\xbf9U\xf2\x18r\x8cB$a\x8a5\xe6\x1aW\xd58Fd\x1db\xa6+\xcc$\xe5\xb5{\x1b\xdfu\xb2\x13\xa1'
        b'\x08\xac\xc9\xb14\xc3O&Ua\xaf;\x8crC\xa48\xfa\xcf}\xa8D\xb8\x8a\xbb\x84v\xc9\x9c\x02\x94\x1b\x99\x82r-\xb8\x06\xb8b4\xfd\xde*\x80\xc7\x98\xbd|\xd0\xd2\xba\xc3 X\xf4\x06`\x9a0\xd9n\x8e\xf8'
        b'I\xfa\xfe\xf7\xf7\x08`|5\x92\xe1@M\x8eb\x8e>\x04\xf9\xe6\xe1\xf8\xeb#Ko\xfd\x92\x94\x91\xeew\xcb,\x0cr%\x9c\x8d\xafC\xb4e)\xb7\x86\x91\xb1\xc2nh\xcf\xa81\x19\x80\x1e6\xc9\xa0[\x0fal'
        b':\xfdI:g\xff\xd1\n\xd3)\xf5\xab\x10o\x9c\x92\xbaE\x03e\xee\xa0)\xad\xe0I\x92\xcbU\x88&\x08\xc7\xda\x0b\xebA\x05N\x06\xdb+\x16\xdb\x1e\x8d\x9a\xe2\x17&\xda^\x8f\xf1\xc5e\xbe\xb4\xb6\xd0,\x8b\xe2\xa4'
        b'\xfdH\n\xfe{\x7fW]\x0f8z\xf0\xe2\x10\xfc|\xea\xa2\xe9\x9b\x98\x87\xa1\x89g\xa9T\xe0\xfaoApB\xc6^\x14\x0e\xc5\xd7I<\xb9t(\xa4&\xb5\x97<2\\@<\xe2?K\xbb\xdd\r\x12\x0e9g\xc4'
        b"\xd2M 9\xa9\xdc\x9d\xb3 P]\xe3\xe9\xdd\xff[\xe0\xe2\xdb\xaf8\xf1IF\xb4'\xd2\xb1\x95yF\xc2\xd791\xccfq\x85\x1f\x0b0rW\xdbq\x1du\x84\xcf\xf0\x02\xf2\xab\x8fd\xcc7\x806\xbd\x13\xec\xd7"
        b'0\xae\xe1\xccU\x81f\x85\xbc\x1e\xc6\xda\x9e\xd0^H\xd2\xba\xbb\xb9\xc6\xcc\xe4\x17\xd1\x892\xa7\x0b\x0f\xef~\x8a\xacKN\xc3f\xdaL\xac&\x7f\x05\xdd\x049\xba*\x1f\x02\xf3\xd8\xc06\xcb\xf0H\xe3\xfd\xaf\xd5\x1f-'
        b'h\xc3\x08\xd2\x84\x1d\xf33o@\xdb\xfd\xbb\xfe\xb0kAa<(\x14\xca\xacX\xca\x92\x12\xae\xf3\t\xd8\xbd\xa3\xa2\x82\xc2g\xd3\xee\xd0!]"\xcaE.{Z\xfd\xed\x02\x02-\xb0x\x08{\xf6^3\x84j\xce\xdd'
        b'RX\xba\x03\x91\x0b\xf5\x98\x9d*\xf9\xb4\xb5\x0c?\xc1\xb0B\x04\xd4\\\x80\x8f\x0b\xe7dR\xc9\xdd]\xb6\xe6b\xdc\x88\xfe\x83-cV\x12\x89Y\x0f\xaas9\xa8]\xdc10a\xd9\xd2\x1e\x02x\x0c\xda\x0c+6\xdd'
        b'\xb7\xf0\xb4\xf7\x06%\x9e\xcd\xd8I|\xb8\rV\x10b5\xf8\xf9\xb0)\xcc\x0cj\xaa\xe4\xd7u\x98\xad\x98H\xcdJg\x1fC:\x8c\x97\xb9\x8dv~\xa9B\xa2\xc7;\xac\xa1\xff~\x1aG:W-\x84\xff\x1b\xc2\xcd\xd5'
        b'\x0e\xe0\xa2\xf6\xa7:N\x81x\xa6\xbe\xde\x14\x07N\xb7y]i\xd1\xf0\xa5T\x8bn3U\xa4_\xb8\xefQn2\xeeN\x05g\xb8\xd9\xc8\x07\xee\xcb\x9dy\xf7\x94 \xd4R\t9T}\xbe\x84\x15^P{\xb2\xe3\xd8'
        b'Iv\xd9\x89\xaa\xe1\xa2kE=+[\xc3\x16QG\xb3O\xffn\xc0\xd3V\x05)\xdb\xab\xff\x05\nfPi\xae\x1c\x06\x14\n\x18\xb6\xf1\x1fz\xc4\x19\n\xa3\xe5\xde\xba\xee\xd1\xa8\x87"\xb3\x97\xe70`CG]I'
        b'\xf4-\n\x1ca\x03\xc1\xaa\xb3\xfb\x97\x91\r\xe6\xda\xa8"<\xd7]"\x96\xa6\x90\xcf\x04C2N"\x9e\x9e(<G\xb0\xaf\xc4\x19=\xad{L\xb9\x9e\x93\xd5"\x99\x009\xb9\xb1F\xd1\x99\xbc\xe0\xeb\xd1\x82\x8a\xc7$'
        b'4\x82\xc1-P\x1a\x89\x84^A\x81\xb0T\xb6\xd9\x03vCJ\xf2\xc1\x9f\x9b\x93I\x81\x97H0&\xcd\xbfgB\xb6\xccS\xba\xafS\xa3Md\x86F\xe0\xcbZxg\xad\xe6\xc7\xfd^\xdd\xc3\xaf}o\xc482\r'
        b'\x8c!m\xc7&\xf1\xca\xff3\x06\x87,o+\xa2\x9c\x0c\xaff\x03>lz\xff\x92\xc8\xd7\x9ak\xfc]L\x03*\xf9\xaa\x9e\xd5:%\x9a\x8e.\x16\x1a\xfe^Q\xef\xb5\xe5O\xd4cG\x90&\xd4\x7f\xf7\xfb\x8d[?'
        b'\x90\xac\xdapv\xb3\xee\x0b[\x83\x10\xfc\xddn\x8e\x04\xe6\xd03-\xbe\xb6\xe1o\x18=]44fe\xc0\t\x8e"\xcb\xa4\x81mN93\xa3\xf9c\xe14D\xf5\xe52\xe1\xe8\xdf\\OT\x99\x00m\xf2#|\x17'
        b'\xe5>\xd7\x18\xb1<Szc\x90t\xf0>\xde\xe6\x95\x15\xa1\x8c\xb0UD\xd2\x80\n\xfd|%\xa5\x8d0\xea\x02\x9e\xd2.\xfaN\x1c\n\x99M\xe4\xdb"\xd7\xb4Y\xae!!\'\x15L\x1c!\x84\xb0!\xc7\x8c\x10:i'
        b'r\xf7z\xbe\x06U\x14\xf5\x91\xaeL^\x0b$\xf6(\x90*\x7f\x1d\x1d\x0cPn\xf9=\x00qr\xc8\xfd\x19N\xb0\x8d\x0c\xd5xA,"7\xd8\x11Gc\x05\x8b\xbf\x19?\xa4\x1c5\xf8P\xf0\\\xc3\x92\x93\xf6\xdbM'
        b'w\xeba\xf7\x01_W\xb8ko\x8dr\xbb\xd0\x19\x97\x9f\xb3\xc2\xff\xa6"\xef\x0f\xdfP\x17o;\xda\x83\x0b\xa5/\x1a\x9b\xdb\x95K\xaav{\xf3\x0c\xee\xba\xc47\xe1\xdcH\xb8M]\xf1h+62\xc6\xbd;\x86B'
        b"\x85SC\xe6\x88\xd5{\x93\x9c\xec\x8c\x80\x01\xd5}\xf4n\x91*\x99\x94ddzt\xf6l\x17\x82\xb6\x9di=\xc3\xed\x04\xac\x1e]$/\x91\xc5M\x1b+}\r\xb1Z\x92\x82\xd3\xf7'\xd4\x01\x85h\x02 \xfc\xc1+"
        b'>^\xaf|yY\xbb\x1f\xe6\xb4\xa4<d\r\x1c\x7fh\x94}Fq<\x05\xcf\xe5x\xb3\xa5Tn\xec\x07\xa3*\x0e2:B\xd9\x846\xb8\x0b\n O\x14\xfe\xb5\x18\xf5\xb8\xa4\xcfW\x1aIcA\x9a\x08|\xe2\x13'
        b'\xe1\xda_\xe1\xd60\x9a\xab\x9b~!\xbd\xa5A!\xf8ig\xd5p!4~\xb7\x83\xa8\x1b\xc2^\x8d\xb7\xcc-\x90\x9c\xda\x17q\xce\xe5\x1b\xf3\x95F\xe5C~\xf9\xe2q\xe1\x1c7\x8e\xf8\x02\xa4\x9f\x88\xa7-\xb5G\x0b'
        b'\r\xc5\x92\x9b\xea\x8d\x15\xc1\xceNi]\xee\xe0\xb5E[\xe7Q\x9a\xfdj\xe3m\xdd\xd0f\xdbX\xe45\x17\x9d\xfa\xc1\xe5\x12\xc4\xa6\xb4\xaf\x87\xc2\xc7\xf8\xf9\x19j\x93Y{]X\x13bz\x87\x9f\x01Z\xd2U\xd8S'
        b'\x81\xaf\x84O< Qf\xca9\xa2\xb3\xb0VL5\xfa\x84\xa1 \xadw\xa0\r\xe1LbWe\xe8\xbdG\x9f\xff=\xf8\x98V(\xcd\r\xbe\xaf\xeb\xc2\x8e\x03%!\xc5\xb3bthU\x0f\xf6\xe3`\x90\x1bu?@'
        b"\x19\x93\x85){\x9b\xd3P\xea\x13'A\xe7\xff\xcd[:\x13\xd2\x19e\xad\xcdP+\x06P0=9\xc3\xab\xee\xb6\xfa\x08\x10\xf4\x93\x08\xc8F\xf9\xb4'\xc1y/F\x88\xe2h\xf5\x13R\xef4\x1d\xc0[@\x80\xda]"
        b'\xf9\x8e\r1\xc7\x8c\xf2\x1a\xbe\xdd\x89\xba\xce\xca\x08\xd4\xe8a\xb9\xae5g"\xcc\xdf\xf5\x00\x9dma\xb3?^\xa7)\xf59\xe5\xc4\x15=\xf9\x88Xsa\xc0%\x806\x18\xa2\xd1\xb1+\xf0\xeb\xe4_\xdfO\xf9\x08W'
        b'/+\xe6.\x1a\x00M\r\x83c\xd0\x03\xf3\xff\xd4\xccU\xe1\xccY\xc3\xfcm\xb84xB\x84\xa7s\x940\x01\xbd\xb6\xbc,\x0bq0\x99\x9b\x06\x86#=O\x15\xdf\x13e\xa2\xa9\x95\xaf\xcc/\xd8/\x8a\xf4\xcf\xfc\t'
        b'\x01*S\xc7\xdd\x0c(\xf4Yqd\xbd\xe7I\xc2\xcbDR\xb63pr\xbd\xc4\xd8MF\xd1\xc3G6?\x12\xfc\x8b\xa97$V\xe2\x98i\xca1d!\x8b\xa0\xb8\xfb\x92;\xc3\xe8X\xd0+\\\x1fF\x18.\xb6\xe4'
        b'\xe1lN\xa3\xea\x1e\x97~SM]\x05\x11z\x06q\xa8\x1a!\x81\xa0*\x11H\x034G\xf9I\xb6\xc7\xac\xf6\xfbO\xda\xf6\xcf&\\\xea\x9e\x06\xc4*\x19\xc2\xcf\x0f\x91r\x8d\xeaf\xd6[\xec\xf1\xacV_\xac.\x8f'
        b'ep\x83\xd8\xf7\xa0\xfd\xa8\x113\xf1O\x1c\xe6\xa8z\x82:\x15\xf3\xbc\xe8F\x8d\xb3\xackp^T\xcd\xf8?+\'\xa5\x03\x91(p\x84L"\xca\xf61\xfa\xda\xd9\xf3v\xafnM\xde\xf4\xd8[0_G\x14~k'
        b'\xf2!\x06)\xaeq\xcf\xe6\xefQ\x82\xd7\xdaw\xac\xa4\xc0QG\x8c\xca\xc2\xa9\xe8S\xe25\xa2\x85E\x82\x99Pm\x1b\xedPp\x9c|r\x06\xc9\xb4L\xbd2\xc8\x06\xb6O\xe8\x1b\x04\x8d\xd2\xb1l\xc4\xecB$\x8d\xc5'
        b'\xcb\n\xd6\xf1\xec\x851D\xd0\xc6q\xfd\xff\xd2\xd8>\xc5\x8d\x1b\x8b1\x9a\xad\x84/Kx@e\xb0?\x97m$\xad\xa4 *\xd90d/\x15q\xbc\x99\x0f5A\xa1\x07n\x0eD\xb8\xeb\n3\x1a\x88j\xef\xe2\xbf'
        b'v\xcf\xa1\x0e\x91\x89\x1c\x8d\x8a\xe5v\x18\x03CA4R\x13\\\x84\ti\xfb\xfa{\xd6\xbd6Gl\xb9\xa8\xfb<\xe3\x1c2\xb8\x9d\xb1,\xa3\xda\\\xcf\xa1\x87\xca\xea\xb6J\xa3\xd3\x1a$xO\x94+e\xb9\x0f@P'
        b"&C\xa3\xb2\xdb\xc1\xdbc2p\x07\xb9\xa70\xd9M_a\x9f\xb7\xe9n\xc0\xc3N\xd5.\xe4!4\x19'\xc44\x18\x98\xff#\x02N\r\xa9\xe2\x1d4\x8d\x06\x9bfGc\xc2\x19\xdd*\xdd\xc3A\xab>\xa1wi\x1f"
        b'7\x07{j\xf5J_\xab\xacA\xce\x98L,O.\xa9TS\xfdz\xd8Bys\xb9.\x83\x97RD\xd8f\x948\x83\xc2\xca\xff\x13FX\xcb9_!\xde\xbd\x94d\x1e\xe7\xe0\xb5R\xe3\xeb\x80\xb4\xf0\xc7X\x91\x03'
        b'w\xc5#w\x0e\x9b6\xd6\xbbE\xca\xec\xa7\xcdf\x06\xaf\x92r\xf4ts\x0ci\x81\x1e\x19\x96\t\x80 O\xd1\xa0\xd8\x15\xcd\x14\x9b\xe8\xa1\x95\xa5\xfc\x914\xe9\xfa\xba\x94}\xbf9\x81A\xdek\x0bw\xc3d}\x8bg'
        b'$\xf8~\x1f.\xc3s}4\xfe\xf1\x7f}j\x13\xa1\xb7\x82\xe1\xc4\xa0\xfa\xac\xa0=\x90\xbb\x86\xa0A\x83n\xf7\xdb\xca$\x98\xfaG\x1e\xb6.\x7f\xedo\xf1;\xad\x9d\xa9\x12\x11j?\xc0\xc9]12\xc8\xe8O\x92\xe0'
        b'r\xb0\x84\xfb\xc6\x96W\xf0\xcd\xb5~Z\xed\x99\xb9\xbc\xa1k\n\x9b\x93|\x7f\x15\x14\xa5 \xd4\xd2\x83\xf8\xa5U\x03\xf0\x1d\xcc\xd0?aT\xba#\xb5\x89\xfa#\xac=b\xbbW\xefI\xa1\xc4O5\xf8\xcd\xb9\xff\xf2h'
        b'\xd1\xc3&\xd6\xd9\xb1\xf9\x14\x00,\xa6\xb2\xa9.x\xe4T\xb7M\xc7\xab\xfe\xbb\x0f\xcf\xe7\xc6\x1fA\x11%\xc8\x8cb\xa4\xad\xbc!\xcf*\xca\x04\xc3\xbe_[\x97\x968\\\xfa\x82\xb3\xa0Z\x00\xf8o\x95"\xae\xd6\x1aS'
        b'\xaag\xd1\x16\xd5@\xba\nSgg\xc0t\x1e\x91\xee\x1cA\xae\x83\x15\xcd4\x04gw\x1d$\xcc\x95\xd2f$4,\x11\x8d=Y\x1e[\x14\x1f\x0c\x87o\xa3\xf2q\xaf"\x9b\x1c\x80\xed\x1a\xa4&\xf1\xc3\xf3\x9e/\x99'
        b'\\\xfe\x90\x0cd\xa7\x94\x8a%0\x06\xf5F-\x02X\x810S\xa9\xad\x94\xb1\xb6\x03W\xbf\xf8#\xc1Nv\xe5+1&\x06\x1c\x166D\xfe\xd0\x84\x00\x87\x83z\x01,zQ\x12\xd1W9\xf5\n\xc3;Q\xa0\xb4t'
        b'+S\xc5Q\xe5\x03b\xa1\xc9\xd7\xc5\x84fCK\xdb?I\x8b\xf7!\x8c\x7f\x14\x9e+&\xad\xec\xdd\x00aB\xe4\xd2a\x7f\x95{c\xbe\x03\xcf\xa2\xf1\x0c\xc4o\x03\x86\xfc\nj\xebRIQ\xf2)7"R25'
        b'-hy\xd3-\x12\x811\xa3i\x85\xb9\xbd\xa4k\x80^\xb4\x1d\xa4\xcaF!\xc6\xf7m:\xa5\x01W\xaa\xc4`\xbf\xdar\xd5\xea\x067\xbc\x88\xac\x07\xf3\xe6\xd9\xe3\xf1O)\x1a\x837\x03M\xda\xc1\x18\xfe\xe1+4\xc2'
        b'\xff\x104\xed\xc6\xd3p\xc4b*\xc3\\F]\x89y\x88ul\xe8\xda\xff\xac\xcaU\xff\x015\x82>v\xf8\xbf2\xfa>\xcb\xd8.\xda\xb1\xf0\xfe\xa7\x05W\xa0\xb7X\x1b\x0e\xbd\xef\x0c\xbcm\xb1\xdaI\xf7\x1f\xc7\xa4\xc0'
        b'\x8a\x96\xfc\xceJ{\x11\x04<|.,\x9cq=4\xcdv\xfc\xe6{\x08\xe9\x8e2N\xe0T\xdb \xcf \xa8\x86\x88\x9b\xa1^\x96\x88\x82\x80\x98\xa7\xc6\xb2-\x18>@\xf6\xd6/c\xfb,#\xfb\x0cv\x11\x1a\xf3X'
        b"lc\x98Z\xbf\xa6\xb8c\xdfA\xad\x16~C/\xf6\xb6\xbfuT\xca+3\x8cow\x8d\x97\xee\xb8\xf9\xfbF\x1b\xc3\xf1[\xa6\xa1\x03\x1f\xa0\xf01\x8bN8\x82l\xf0\x80\x84\xd3\xd4^\x1f,B\xd8\xc4'zF\xba"
        b'\xed\xca\x8cy\xf3\xeaT\xe8[\x12\xc4\x93\x83(C\xf1\xf58z\xc8{\xf09da\x817\x00o\x84\xee\xbd\xf2\xae\x91T\xa2\x07}\xcb\x88%\xe7\xf6\x04\x87^]\x86\x10\xca\xd9\xcbG\x1d\xa4\x15;\xafm\x05z\x1f>'
        b"K\xe3\x02]E]\xff\xca\x15\x9b2\x93Y\xb1\xfd=\x9f\xd0\x1d\x95B\x10\x9910\xc65\xd55\xaa\xd4\xfcg=\x90=\x12?\xae)\x98Mh\xac\x03#\xac<l\xc2\x8b\xa9'\x97!\xc5p\xa1\xae\xa9E\x0b\x879"
        b'%\xd86\xd2\x0c\xa5-o\x10"CS\xbe#\x81\xb7\xafp\xbc\xc3\xa8s\x80T\x9d\xc7\xe2v\xd8\x18l\x8c\\\xda\xf6\x8e\xff[P\xe9c\xb7\xef\xef\xccM\x07\x06x\x11\xdeqsG$\x96=m\n\xed<\x81\x14\x08'
        b"\xe8\xc1\xc0kvH\x98\x80)-\x00\x97\x99\x9b\xb7\xacG\xc7k\x14\xbeTX\xa6\xaa\x12@g\x82\x0ba\xc8B\xc3\xe3\x12\xe9\x1f\xb76\x8d\x95\x1ej\xc7\xa7\x83\x91\xab\xbc\xa1wlq\x8cffJ\xa4\x10\x1c'\xed\x8b"
        b"\x94X\xec\x81#r_.\xfe\xec'S\x00\xb6Lf<z\x11$t\xee\xa6\xc7\x83\xf1L)\xb3\xaf\x87\xd0RP\x1b\xb2\x05\x80\xc3I\xfeH\xdd\xe7\xf2L\xaf\xff\xdb<\x9eEq\xcc\xf1\x048dg\x90z\xdd\x02\xa1"
        b'\x9e7I\xe4"#-\xf7"\x01C;\xe0\xf2\xe7\xbdd{\xd0o\xff8\xcc\xa1\x10\xe4\x04\x0eSj\x12m%o\xb9\xd4\xac\xfa\x8c\xf0\xb3d\\\x8c\x86\xc6\xc0j\x80\x10\xe8\x90\xe1aR\xa4s\xf5\x13)\x95|\xcbK'
        b'\xf9c\x98#\x05\xe5.\xaf]\xd0\x11\xd1\xc6N\xa9\xf0\xbb?$\xd1\xc9\x16\x8a\x99ZW\x1f:`\xdc\xbc\x86\xb5\x15&\xb1u\x0f\x80*\x8c\x04S\xcb\xeb\x8c \xb5\x89\xd0\x99\x96\xaa\xdd%\xcc\xc8\x02\xfd`\xf4xm\xee'
        b'\xd0XR\x1e\xb1\xfaC\xd3\xc3\xa8c\x0cSo,\x82Uh\xb2R\xea\xb08\x92&\\\xce\xe4\xb7h\x1c\x01u \xf2\xd4\x12[/\x9cad\x03\xb2\x0b\xbf\x94\xa2\x1c\x89HT\xdd\xbb6 \xe0\t\xa69\xdfc\xe9\xca'
        b'\xf8\xc5g\x1e\xed@\xa4]\xc5\xafn\xa1\xef\\\xcb\x93\x13v(\xea\xd7\xf9\xa3*\xfa\xcbd\x17:Ofk\xaa\xf5\x0f\xc0K\xd8d\xe8\xa48=\xcf\xde\xbb\x93\x16\xed\xbd\x8bR\\\xddD\xa9\xf1\xc2\x0b\xf3\xda"\xbb\xfe'
        b'\x8c"\xd8\xa5\xe5\xe1#\x12\xa9\xd2xH\x17\xa6\xd00\xce6P\xb0\x1f(\xceI\xa9\x1a\x1e\xac\xcamZO\xb9\xac>OZ\xbb\x8b\xd9\x1d\xe7\x14\xab\x03\xf7\xe8X~\x1d\xb9\xa9\xa7e\x07\x8b\xddQM\x9b\x0e\xd16O'
        b'\x7f\xdc[^\x89\xe1\x11\xbeJ\xc9\xc7\xceW\xaf(\xe2\xd8R\x11\xd7J\x92\xfe\xd9\x88\x1a\xa3!\x1e\xe4\xae\xc3\x8a\xd7\xcfG(k\x1c\xf2\xa3Ni\xb7 o\x9f5\x88\xca\xf00\xfa\x9c\x19\xb4*x\xcf\xc2\xd8)\x8f>'
        b'\xd3\x9c=\xb9\x11\x12\xea\xbc\x95*\xa9\x87\x11\xa9\xb0\xe8\xc1\xb3\xc1\xedx\x97\xef\xedhM\xb4fD\xc5\x105\xb2q{\x81\xff\x0e\x0f\xee\xb8\xbe\x15w\xca"m\xa6q\xbd\x81\x7fq\xc0\xc7\xa1\xe0\xfe\xa6\x93\x04(\x1f\x0b'
        b'\xbc9`8\xbf\x9b\x8f\xfd(\xb9\xc8\xe0\x89Q\xfa\xa2\xd8\x7fe\xe8\xdb\xad1\xa7VA\xcc\xf7\r\x1da\xe0P\xc9t\xe5\x11\x10[G\xa4^\xdax\t\xc2\xd9\xc5\x8e\xeeCB\x13yV\x87D\xcbT\x17<#]O'
        b'Y$-*l\x15P\xaa\xa0\x899\xc2bL[\xfc\xfb\x19\x8fO1$\xc4\xca\x9d\xeb\xdf\x01\xc6\x14\xe4\xb5\x86\xce\xc55u!B\xe4\xae\xfd:\x05=p\x12\xec\xd6\xd0F\xbcG`\x85{}$\xcc$3\xd5\xd9\\'
        b'\x8e\x03]\xe6!\x8e\xffs\xd8\xae\xd3\x05\xf9\xbb\xdd\x9b\xc9tA\xd8\xb0\xeb\xff\xbb\x02\xd8As\xbb\x01\x98\x14H\xcaC\xc4RB\x7fF\x04\xd0f\x1f+H\xfbn\x0b\x02f4\xb0\x9b\x0f\xf7}^/%\xed\t\x06\xa3'
        b'\x17tx:\xc3+\xe1\xf5I\xbc\x9e\x9a\x1e\xa6\xa60\x93G\x88I\xd1\xb9\xab\xd6\xfc5/An\t(\xeek\xe5\x02\x1cP\x83\xff\x1es\xe2\x87\xc3| \xee\xa77j<6\xfdR\x0f\xdag\x08\xba\xe3\x8cb[\x85'
        b'\x87C[\x98\xfc1\xf5\xaf]\x8d0=\x0b`q\x84+\x15\x82\x89\xbf\x81\xd8\x06\x15\x10\x84\xb2\x18hm\xdf\xfe\x15\x07B\xac\x08\xdd\xe6\xf8\n\x07D\xb1b)H\x1a\xfb"Ev\x13\xd2b2!I\xd8}\x8a\xdf\x10'
        b'<\x0c\x11[\xe3k\xcf!\xe4&\xc9s\xb7\x93G\xde\x89Ak5s\xcd\xcc=\x93\xac\xcc\xea\xd9\xe0\x19\xe0r\x9bV9\xe9^\x02\xa8\x8c\xb7cv)\xe9\x1c\xafe\xa7\xfbq[\xdfv\x0e\xc5]\x9a\x00\xaeU\xe6\x19'
        b'\xb0\xbcPRI\xc3\xa6\xfaj.WJ/\xe5\x8c\xe5\x92\x15\xa1\xbd\xd2\x83d\x1c\xfd\xabM\x9a\xcb\x06\x8a[a\xcb\xf95qh\xc7D\x98\x1a\xab\xe6\xa8\x82\xfd\x01\x0b\t3(P\xfd\x84\xfe#\xb7\xddN\xff\xa7\xd8\x7f'
        b'.\x1a\xe1 1\xe8nYIv@\x10\xd0.B\x89iI%\xf4C\xaa\xb1\xd5\xac\xd9\xd1+{\x12\x02\x84\x97\xba[\xa2H#\xfa\x07\xe4?#\x9a\xf7\xf2\xa4\xfc\x81",K\xa1G\x13R\xc4G\xac\x90\x0b\x8d\xf9\xdb'
        b'\xdc\x8f\xa8\xc7\xa3(I\x96l\x1dWWe\x8d\xde4\xc0\x8c[\x8d\xdeI\xe5\xf3g\xed\xdb\n\xca\xddL\xb3\x8f\xaa)+f\x0bT?\xef\xfe}\xf4\xbc/\xfcXX\x0cEAs.\xa5|\xa8\xfe\xdd\x9dj\xaf)\xb6'
        b"o&;\x10\x1b\x86\xd1\xf2hG\x15\x15\xf4\xff\xfe\x16\xb7\xf0\xd5?\xb9\x87=\x87\xaf\xca:Z\x05JT<\x0bP=\xb6&\xdaj\xc7$BWwv\r\xf0~'\xa7\xb6i3E\xa1\x01\x10&\xe2\x9b\xe5?qe"
        b'\x03%\xe0\xa9\xcb\xf2\xc6\xe7Z\x91\xaff2\x8a\xe5\x08(\xbb\x02\x89\xa6L{W\xc3\xd2\xcc-y)\xe3\xca\xedyv\xee\xbe\xe4\xec\xf5\xc0\xcf\x13\xfcq\xbb\xa0k\x9a\x11\xa2k\xc5\x1f7\x05\x96\xceN*\x94\x1d\xeeN'
        b"\xe2#\xb1\xfa\x98\\\x8c\xae\xab9\x91^u\xa1\x1c'\xda#!\x89\xeaJ\x94\x8eP\xe5\x15\xe9\xa5\xcc`\x89\r\xea\x1d\x99\xb1\x86)o\xe1\x8dc5\xf0\r\xae\x8f\x06\x12\xf3\xe1B\x99\xf5^\x1b\xa0`\xc7\xb1\xfb\xb6,"
        b"\x85n\x1d\xb1\xbc,\\p\x8b^\xb4\xba\x19\xbc\xdd`~\x14\x07pB|\xf463\xd7\xb2\xb0\xa67x\xce\x88\x1e\xefEk\xd5\x0f\xff'WZ\x15\xdd\xfb\xecY\xbcl\x8f\xb7\xfd\x19\x19j\x9e\xdc=\xf4\x04'\xb7\x05"
        b'?\xe0MU\xce\xbe\x87p\x12\x1fs\xe3\xda\xfby\xb5L\xd2h\x8aP.\x8e\xff\xf2\xd1\xea\xa2\x11$\xda\x8bR\xc0\x16YX\x05t{\x97f\xd2o\xf85\xf3\xd4,\x84\xcc\xcf\xbc0\x02a\xf40\x1c<bt\x19\x04'
        b'\xad\xbe\x91M`<\x9d7\x9ew\x9d\x15Q\x84`!zbV\x8d/\x9eX\xe8=b\x95\xbd\rGsd\xce\x81\x83\x11\xb2\xaf&\x0b\xb8D\x02\xb5\xc8\x9aY\xea\xf9\x04\xb9*V%\xb8y\x06\xbe\xacy%c\xe8\xe4'
        b'\xb7\xd6\x13\xf6sl\xdbe\xa6\xdb\x88bf\xb9\x02i\xc8\xa5\x9b}\xad\x11\xeb\x1auh\xb6{\x9a\xdbzon\xe8\xc5\x12\xbdo\xd6\x88\x02\xf4\xd32\xdb7\xba\xf1\x0e\x98\xbc\n\xc2\xa4\x1f$n\xae\xcb\xa36%\xc2I'
        b'\xe0m\xb31nV\x95\xfc\xf3\xebLm\x17\xfa\'\x8b\xd6\x87\x10\xa9"\x15\x8a\x98\x15\xb9[\xb7\xea#\x11A\xa8\xcdN\xe6\xbf\x08\xb9\xc2|\xd0\x0b\xa9rz\x16H\xa7\xf8s\xfb\xbe9(\xac@)\x99\xb1z>m\xf5'
        b'o\xd9A\xcd\xcdd")\x87\x99\x14-\x83\x10*E\x06\xf9\xdb\xc7\x87\x87\xc4\x9c\xfd\x0e(\x9e\x8a\xdf\x15J\xe0\x15Kg\xe2\xc5@tUw\x8d\x8575\x86\x15\xfe\x08;Y\xfc\x955\x9a\xa8-\xf3\x071\xf4\x1a\xa4'
        b'*\x83\x0f&sV\x93y\xf2L)^\x85\x07x6\x85\xa1\x81d\x81\x9f\x01\xd3\xc6\xe5\xc1U4\xfb2\xcd\x85\x1b\xe8\x11\x02\xcbE\xb7\xcc\xe1\xec\x13^WWb\xa1\xa5\x0c\x85Ii\xdc\x91\xfa\xde\x99y\xda,D\x19'
        b'\x13\x9d{\x1b#n#V\xc5\x98ZHSu\x87\x12\xa6o&\x9c\x96\xee7$2\x9a\xfa\x93\xae\x96z\xb0\x87a\xafgW\x8a\xdf\xd4i\xff\x07\xea\xc5Y\xf7\xb7\xaf\xd5\x188\x1a\xd2\xc0\x972\x11\xae\xadyf\x8b\x11'
        b'\x87\rEL>\x15M\xb8q\x94[\x8fu\x89^\xb0\xf3\xb8Dp\xc2\xaem=\xee\\\x08\xfc+.\xa5o\x07i(\x927\x9a\xca\x81\xeeF\x91\xbb\x19\xd4\x18b\xe7\xc3g\xd7=G\x8e\xd1\x04\xe8\x18(\x1c\xf7am'
        b'D\xe7\xbf\xe7\xcb\x13\x82\xbe\xa68/\xb7M<0\xafd,\xca\xa1( \xc6\x93W\xab|\xbf\x9b\xb8\x87D\x8c\xb8\t\xb1\x1b\xca8\x0c\x89\xa9z\xf7\xec\xb6\x1c\xd1\x8c\x830\x89\x8e\xa3e\xc8\x8c`\xfb\x1e3S{\x08'
        b'\x99\x14\x92\x8d\x8d\t\x96_\xec iU\xaf\xc3\x8a\xd6\x9f\xce\xa0$c\x13=\x93\x19.\x7f\x15i\xf8.6Y\xd3\xed\x8d\xc8\x86\x0b]g\xafzq\x9f\x1c\x1f%\xa6\xb7\x07\x12\xbd6\x8e\xd5\x86\x89\xfb;\xb7P\x0e\xe2'
        b'\xb6\x89\x94\xd7[1\x99\x0e\xee\xc9\x8d\xb3\x19>\xc1\x96-Dj\xbd\x1a\xc7\x80v\xe0 L\xdd.\xa3\x96B\x12\x8d1\xa5\xd8\xfen\x94\x80\x02\xc8\x01\x8e\xa9>\x07S`u\x8e~,\xfe\x90~3K\xec@F\x02\x19'
        b'Nr\x8ch}\x8b\x1a\xb2j\xb8O\xe6\xec\x0c\xc6=\x96\xee\xf8L|U\r&\xb0\x9a\x9b+\xf5\xdd\xdf\xbbW\xe2 Y\xb0Z\xa1\xa1\xa8\xf9/p.\xaao\xe1\xee`pXum\xb9\xde\xc9\xa3+ \r,\x0c\x9e'
        b'\xb5\xab\x8e\xf3\x06\xe9D9+3\xba\xa7sg&{\xfd3\r\xbd\xb3\x1e8\xbfx\x9f#6;\xe1\xab\r<p\xf3-\xb8\xe7c\xef.\xc8k\xa59\x06\xbfh\xe8\xfe}\xbcDj\xde\xe1HWw5\x07\xc4\x1c\x88'
        b'\xa8]b\xf6\xc9\xff+\xe8\x0e\x00\x05\x86i\xa2\xa9+\xbaP+\xdbwb(\xc6\x91QX\x13\xff\x08)\x06\xdeCm\xee\x1c"\xb3\xaap>\xed\r\x1f\xe5\x11\xf2c,\x02(\xb0\x03\xdf\x8dqu\xffG\xd2!,\xe8'
        b'\xf4X\xa9g\xee\xd3\xaf\xd6C`e\xef\xba\rBpL\xc3\x00\x01\x0b\x0b\x0b\xb9W\x05{z \xe7*\xb4\xa2\x0b\xeb\xbd\xdaI\xfc]v\xbeC\x0e@^u\xc8l\x18U\xdd\xec\x92\xcd1\xa4@M\xc0\xba:\xa3F'
        b'l\xd5/5\x96\x83EM\xfc`\xcf+,\xe6\xe3\x9e\xb4U\xb8qa\xf0\xfb\xf4\xe00\xf2e\xd2s\xe5\x01&\xdei\xd7Sn\xa5\xe1k\xf3\x7f\xcbCV\x87\xc6\xa0Wh\x0b\xb0\x92V\xd7\xbd\x88\x87_>,i\x80'
        b',\xb3\x13\xba\x14\x05\x9c:;\xa7>+gq\xb6\xf2\x1a\xeb!\xb8\x88wnz\x06?\xe0\xaaa\x06\xad)\xb5\x08\xeeL\xd9\x03\x9d.\xe2v\xcd\x9f\x83n\xd9\x04w\x19\x10\xfb*\x82\xaa\xb5\x93\x0b\x1ac_v\x01"'
        b'\xef!\xbf\xe2\xc4}\x9eV\xf5h%\xb5\xe9xPZ\x0b\x86\x96hG\xfe\xc4\xadz\rO\x1d\x99\xdf<\xc1.\x1b\xb7\xf5\x17\xf9A\xae\x84\xb8\xd8?\xbd\xa30A\xed\x00G\xf9\xaf\x93\xaad\xfb\x1a\x90\xecj\x07\xe9\x8a'
        b"\x12.\xb13<\xe4\xcdR\xe5\xcf\xb4lFd@N%<\x10\x18\xed\xc7n\xb3\xf0\x12~M\xd4'*\xc8\xfe\xabX@\xe4w\xd6\xa8\xc1\xa20oh\x08\xf1\xa4\x02\xd3\xed\xe5{`\xb7\xb5Rz\xbe\xa6\x86\xb2:\xc8"
        b'\xa1\xdawIB\xe3H\xb9\xbdy\x99\xd7\x92\x0c\xe5\x12\x0f\xec\x9d\xba\x0f\xf5\xa1k\xd6u\x82\x9ea\x03\x0e\xae~Sa\xb7!%\xb4\xfa6\x982\xafH\x1f4\x95\xbc\x8d_\x8ac\xe0\x7f\x16)P\x1b\xea,\xd0\xe35'
        b'\xad\xb8\x9dz7j\xc6\xad\x8c3;\n`\x87\x0bT\xbd\xb4A\xf4,\x17\xb4\xd8\xa0:\xb8\xd6G\x82\xcd\tf_j"\xcc\xf2s\xc9y\x1f\x1faX\t\x8c\xfcCO{\x0c3\x9e\x7fr0,S?A\xf2\xd3\x84'
        b"\xf0\xc8\xc8>\x1c\xf1\x02\xa5\x9e\x80*\xd5Y\x7fm\x0fg\xa8\x18h\xc8\xe2EC\x8f\xd0\x85.H\xc48-\x99p\x8f\xb2b\xf4un\xfc>W\x04p6\xc4q\xa1u\xef\x9aE\xdc!\xfc\x11'\x96\xc92\x04t\x1f"
        b"\t\x91\xbf\x1aYqU~)~\x15C\x17\xc8\xf3J@:E\xd7R\x8d\xf9\x9e\xc8\xe1\x1e\xb7\xbe\xfb\xb9a\xe7u\xc1\x9b!\x8d\n\x8aa\xc0\xd3\x81x\x133'\x84f\x80\x96\xe8 Phf\x13\xbf6\xaa\x9a\xb6x"
        b'\xc9\x8d\xba\x1a\x0c\xd1\x83\xcb\x06_\xd98v\x96c\xd3\x9f;\xf25l\x18\x92\xda\xa8,M\xe1\xc3A\x1d\xab\r\x9a\x0b\xc4r\xea\x1c\xdeR]\xa2\n~\x7f\xdbL\xf5\x14\x80\xbb\xa1\xbeE$`\xec\x9c\xff\x97\x90\xce\xb9'
        b'\xc8\x8f\x98\xb7\x04\x92\xbfo\x9e\xaa\x0e2rH\xc5\xfa\xff\x99f\xd4\xbfd\xcf\xf1V\xfc\xbd\x05)e\xc9\xb9]\xe1\x02M\xf5J\xe8\x94\xb6\x9cSw\xe1g\xc5P;c\\\x05h\xc8\xc4\xb8\x7f1"\xe6\xca\xab\x99\x01'
        b'>\x9d\xe8>|\xc8\xedj\x90\xce\xc7d\xc6\xber\x9b]^?\xca\xa238Y\xf3\xda\xec\x90\xdcf\xcfe\x1d\x05\x8c\xbf|a\xed4\xa3\xcf\x93Co\xa9\xe6o)n\x157\xb5\xa8\x18?\x8b\x93\n\xb7\x10\xc5\x18R'
        b'\xbf\xd8N\xdbJ$\xd2@\x16\xeeI)\x05\xb0]\xca\xd7W\x00wosK\x9b\x1b1\xc3\x9b\xad\x00\xa1Pi\x00j\x99\x14\x94\xc6\xca\x82\x83]3U\xeb Bk~\x0e3*\xf0\x1dE\x9d\xcd\xe8\x94j\x89\xa7\t'
        b'\xcc\x16c\xc1\xbe\x1d$w_\\\xd0\x8a\xf7X\xea0J#Z\xc9\xb3\xc2\xf0\xc4t\xf5\xa5\xdd~\xc0\xa6\x0853j\xde,\xe4\xa2\xf2\xa3\xf40\x11\x00\xcaCD\r\xe7\x19\xa2\x8b\xe5\xdd\x82Ux\x0c\t\x15\xb6\x1a\xfb'
        b'\xc6D\xe2\xfb\xbf\xa5\xb1\xc8\xa6\x8c\xdf\x80zix\xd1\xad\x8c4\x86\x9e9Y\x1f\x81\xdb~N\xec\x11\x8ck\x06\xb9\xa1j\x19\xb63\xd0e\xado`\r\xf9\xbe\xd0\xfb6\xdc\xa4@Hn\xf4\x82\x93u5\xd7\xcf\xd0?'
        b'\xc7\xed\x94@\x0c\xb4/\x90_\x8c\xa5\xac\xbcf\xd0\xef\x9c\x13\x9b8\xf6\xea\xcfh\xbc\xb2\xb3R\xec"\x08\xc9\xfa\xe3\x0e\xa5`\x10}^4\x10\x9f\xd5\xcb\x07A\t\x18\x9eqZ\xc6m\xc3zJ\xf7\xcdb{\x0c\xf5<'
        b'\xb6\xf8\x95;\x80\xf8\x9c\x9d\x08j\xfc\xdc\xbd\xc1\x8e\x00\x9d\xee[Ia\xe0x&\xb2!\xbe\xa2\x99\xd2\xa7\x95\xc2\xc3\xb2\xc6\x86\n~\xe5\x84f\x16\xbbw\xa3\xe3\xd0\x9c\x12(\x17_b;\xf2|\xc7\x0e\xb5<q\x1d\xc1'
        b'#\xd1w\x02\xe3\xf9}r\xc1g\x90;\x90\x18&\xe5\x9b\xfc\x12\xbf\xceU\x1b\x8e\x82o\xd9h@s\x862\xd8\xe0\xa8_@.)\xb0D*\x9a\xe9\xb1\xb6\xf5*$\x1d\xd7\xb0\x02\xbc\x15Z\xc7\xd6\xa0"8\xb3\x7f\xfc'
        b'77%m\xaf,\xbf<B\x10\xdb\xdf\x10y\x0f|\x89=\xc9\xbc\x00\x9d$\xd9\xbd\xab\x88\x00\x90X\xa8\xc9\xd0\xa0\xe2\xba\x99\x15\x87\x86\xdcYT\x97\xf8\x89\xf9\x0c\\\x85\xe2\xf9`MY\x16d\xdaF\xe5\xeb\xad$\x91'
        b'\xcc\xa2\xf0\xa9?]W\x01k\x1d\xf1t+\x11h\xfa\x88J\x8f\xa1sG;8B;\x95rn\t\x0b\x9aq\xc9e2\x00"\x02@\xb6\xa6\x18-I\xa7\xe6\xd3\x8a+\x1bl\x13u\x94\xcf\xa2f\xcbd\xd4\xe4\xa8\x18'
        b'r\x18\xc2CT18*\xe7IX\xb8\xce\xb0\x10\xe2z"\x08\xc4\xc8\xc6\xe9wt\xd3\x07s\x1b\x9e\x123R29\xa1\x06\x1f\r\xc9\xd3\x9e,\xc1T\x93\xaa\x13\xa4\xf4\xfd\x89x\xf8\xd2p\x988\x18\x17\xb7\x95\xb6R'
        b'\x90\n\xf6\xaf&R\x03\x9c\x87V~I>\x80\xc9{\x99\x0c\xd1\xcdNm^\x9ab\x14\xddW \\]\x92f\x93PCY_\x96;\xbe\xfd\x04\x00\r\xc6b%\xc2*\xdc\xda\xe5X\x844_\xe1\xc3g\x01\xc8\x93]'
        b'\x84\xc0kNi\xc1VU\x88\xeb3\xdc\np\x04\xd5%\x84}*U\x99bJ\xd6\xce\x95\xe5C\xcfQ\xbc\x85\xd4\x01\xc1Y:\x03\x8ekn\xf8\x98\xbe0\x19 \xb3\xb1\xf5\n\x0fY\xe1\xb8\n\xa2\xe3&\x19\xba\xc6\xa8'
        b'\xc2\x93\xf3O\xb2<\xcc\x8f\x81$\x87?\xe3*\x80D]\xea\x84\xea\x92>V\x14\xa2\xfe\xdf\xc4s\xad\xcata\xf1\xb7O\xe0\xdb`\x0c\xf6M\x87\xa3[y\x97O\xe9\xc4\xb4\x8e\xb2\xbbj\x10*\xb0\xc6\xc1\xb5 \xf8\xf8'
        b'\x94\xa3\xe8)7\xce\xf8O\xec^\x82\x8f*\xe5\x1d\xca\xf5j\xbc\x83\xc8?\xd7\xfd^\xaaI5X\xcduff1x\xcbG\x17\x19\x95WK\x13`\xf6\xf5\x8b\x9d\x8e\xfd!\xc5\x97\xab\x8am\xb9G7\x92h\xb5\xd8\x03'
        b'\x1du\x121\x89uR@\xb2:\xeb\xbb\x7f|\xa6pR\x9f\x85P\x91\x1e\xa7\xf1\xd9\x82\xc3-G\xdc0f\x1b\x89\x01\x7fR9p\xa6\x98=\xc0\xe3\x83$\xd4\x96\xaay:\xd44\xe2\x06\xe7\xbc&\x9f\x8b\xba\x88\xfcS'
        b'\xea?\x1f\xaca\x1c\x0bQ\xaetry\xb1k\x95u\x91\x16\xa0={\xf3\xfa\xc7\x90X\xa0\xe8\xff\xd0\x88#\x10\xe8X\xca\xc3"W%\xe7k\x96@\x92\xe8\x86X\x06\xbf\x1f\x92i}O*\xcb\x82\xc8lS\x88kd'
        b"rr/\t\x88h\x1d~(\x0c\xc4s\xc4\xdb\xedd'\xe7}ei9ooB\xa3X<v\x96X\xd9u\xdd\xb6^3\x96[\x8a\xad@\xd2\x7f\xf7\xa4\xa9\xb5d\xc9\x92\x19Y>\n\x9bK\x91c\x88\x06\x90\xabw"
        b'\xf2\x82\x1f\x02\xf8\x16\xa8%\x1d)\x87Hx\x9a)\x1d\x96\x11\xd4\xfe\x9cuU8\x19\x84\x88\xbd\x88\x90\xb1\x82\x05\xde\x1f\x14\xcb\xbf\x8c\xa5\xb8\xb8\x17&\xcev\xe9B\xe0.-#\xf8\xfe\x0c?x\xa2\xc4qi\x0e\r\x05'
        b'!O\xf7It\x1e\xdc1L\xb6\xe07[\x1e\x96y:uW\xf1\xe7\x97\x9c\xd8\x16K``\xfa\x80I\xa5\xc6J\x9c\n\xf5\xac\xc0HW\x90bYx0\x9ey\x89s\xb7\x16Cq\x06\xe5.\x04\x0b\x93\x04W,\x80'
        b'\x8cq?\x8b[\xd8\x99c\xce\x9bX1\xa6\xdd\xae\xb6O\x03\x1f4\xec\x16x\xa1\x0c}u\x10\xb4\xf3\x95\xcf\xd4l\xb9\xfe\x9c\x1eIl\xad`\x08f\xbd\xa61\xc3eS\xca\xd0\xc8^@&j\xdcz7\x9ad\xdc\x83'
        b'\xdf\x80R\x15(\xd5u-\x9b\xd8\x1dJ\x01\r4!\xdd+c\x15u\xfb\x87;\x80$\xe2\xc68\x91@\xf9\x18\x8b\x9d\xa4?\xe5\x9e^\xccb\x8b\x06)Z\xd3p>6\x96 WY\xae\xd2\x94\xc3\x91<yU\t\x14'
        b'Nc\t\x99\xccB\xc7IIK\xff8\x82/A\x96\x8f\x81\xcf\xae\xb9:F\xf8\xb4`\x14;+\xeb\x17Fm*\x02_\xdb\x8d\xfd\x93\xd1Y\x8a\xb4\x15\xafAc1:\x06+\xe9\xe35A\x93Y\xb2\xde\xdb\xf5^\xa5'
        b'\xc6O\x82\xe7#\x06\xb1\xc4A;U\xa0_\x94\xe7\x04\xbc\xdf\xa8\x91}_R~\xd8\x18X[\xf1\x9fV\x85<M\xca!\x16\x13&\x8cM\x98\x9c\xed\xec_>\xb6\x89\x0e\xc3o\xb9#\x93u\xa8\x88\x88\x9eZ0C:'
        b'\xc3\x9e\xa3-&\xf7\xa6,\xba@p\xa3\x8bC4\xa0\x97\xc6\xe8\xe4;3\x01:\xbfs\x99\xcc21D\x82\x86\x97\x149c\xfe\x19\xf1]]\xb3[\x15\xc1\xa7\x7f\xce><\x8e\xff\x12\xc3u\xf8\xe22$\xefD\xf4\xb9'
        b'<Em\xc6\x83\xcbt\xd4\x83\x9f\xd2\xbf\xf5M\x92{\xaa\xcc\xf7\x04O\xe2\xc8\x19\x80\x1e\x1b\x98\xc4\x84\xce\xc6\x9eZ<\xe8\x9b\x14a\x1c\x99\xb9\x81o\x1d\x17\x0b\x14\xc3\xbf\x17l5)]\xc3Iq\x8b\xaen\xd3\xb8\x07'
        b'\xe5\xfd\xfdg0\x05\x96p\xb9:\xfa\x10o5\xa3\x89/s\xe35L\xb2\x03\x12\x93n\xa9\r\xf7\xb79np\x96\x1b\xf0\xce\xcbl\x93\xaf\xdb\n`\xd5!\x1e[\x05\x0c\x94\x99\xee\xb2#\xcf]\x12\xad^\xe0\xa0\x894'
        b"\x8e\xa9\xe9m|\xcc|U\x9f*\xd3\x1b\xbc3\xbb*\x99\x85\xd2\x7fvJ\x94\xd2\xf5\xc6\xc1\xe0\xd2\x1e\x0e\xe5\xbd\xaf\xef)\xaf\xd3FT\xa6\x05\x18\xff\xe0\xed'\x84\x86\\1\x11o\x040\xaa\xe9\xcf\x84\xad4\x0c\xde\xe1"
        b'\x84<3\xbeo\x9b\xd5\x1c;\xcbkZ\xe1\xca\x8b\xd0\x17\x88~S\xb2\xa1\x80\xb3\x1fV\xe29ZQ#\xc1\xd4\x99\x1c\xfcd\xf2\xdc\xa4\xa7zf\x97Z\x7f\xb4s\xdd\xcb\xc32\x18\x1a\xf2\xdeN\xb6\xa8\x0c\xe2\xc4\xa7\x0e'
        b'\x85)\t#R\x03\x01\x87~\xb0;\xb5\xd2\xed\x94\xfdu\xf1\xb9\x17\xf1\xe2?\xa3\xba)\x00g\xa5\xf6.M\xeemp\xab\x04\x9f`\xb4\x0b\x8b\xfd\xbdlD\x8c\xe09(\nvMcX"9\x88/F\x97+U\xf0'
        b'K\xbe\xbdb\xba#,\xba\xc4\xe6\x9f\x7f\x01\xec\xa5\xbe\x1fw\xfe\x89\xc09\xef\xeb\xaf\x98\xe2\xed\xce.\x17T\xf4\xfa\xdf\x97\x83\xba\xcd\xca\xff\xb6w\xbb\xc86\xbd\x83Yq\xdaqi\xf7\xb24c\x9e}K\x8a4!\x1b'
        b'\xedp\x03\xb7\xd7\xa1\xd6\xefO\xe2\x99\x9b\'&\x99\xb3>o\xab\xdd~\x00\xe0\x96\xe8\xc4|\x941\xf0\xa0X\x8d\x10<+\xb317\x14c\xbb\x98L\xe0"p_\x06\x95\x98\xe2L\xce\xae\x16"\x85\n&\xeaI\xb7\x17'
        b'\x97 \xfc\xf9{\xdd\x82\xe3Q\xa9\xcc\x1b\x9dh=\x1f\x96\xa1`\xc2\xde\x90\xd5$\x8a\xd0\xfb]G\xbdfs\xc5\x86\xac\x9c\x8c\x15\xec\xbb\xb4\x9d*\r\x16T\x8b\xfeD}\x98\xc0\x97\x0b\xad\x9a\xc7\xd59Lr\x1b^\x1c'
        b')vX\xe2D\xe91\xe2\xdb\x05\x1c\x1d\n\xca\xfe\x1b\x98\\\xda\xe3\xe7C\xa5\x1d\xae\xb3V\xb0\xae\xbeL\x06\x0c\xd9h\xaa:\x82iy\xc7\xd3\xeaD\x19\xc3\x89\r,\x13\x17\x9c|\xde\xe9\xc3\xcc\xd8B8Z\xeas\xbd'
        b'6\xa1T\x10\x97\xba\x82\xa0\x1b\n\xeax\xe2\xa4\xd8B\xb0\xb8\xc8\x10r\xd6\x0ed\xe1"{b\xa3\xa1\xafn\xbd\xb8\x84\xa8\x16\xeay\xacl\xed\xdfZ\x1b\xd4*\xa0G\xd7=}\xc2\x919\xd0.\xe5\x1e:\xc4B\xbf('
        b'\xb8\x177D\x0b\x87\xb0\x9fC\x8aj\xceVX\x1e\x11\x13"\xd5\x02\xf8\x9fw\x8cJ1\xaa\xef6\x0b\xaa\xfe\xbf\xa1\'PUV\xc9\xad  \x0c\xd3\xcf$1H+\xbb\xdc\xa4b\x8d\x03\x00j\x1f\xf37\xb34\x07\xed'
        b'\xb8\xdc\x03[u\xefQ\x19\xd8\xeb\xe5\xd7,\x16\xcdNQ\xa6\xb0\xb5\xd1\xccX*c19\x1a\xb2[m\xef\x01\xed\x9e\xf3hy\xad\xf7C8B\x0f\xce\xc1k\x95\x8b\xd8;L%`k{\xd4\xb8\x97n*\xd0\x18\xcb'
        b'\xd8\xe9\xb8P\xc17m\x03g\x84\xfe\x0f\x0b\xb2#F\xbag`\xc0a\x9d\xfa\xaeX$\xf2(`m,\xd6\xf7C\x8f\xd3}0\xad=q&-\x17fo\xdaPn\x1en\xa4\x8b\x06\xe9\x01\x00\x00\x00N)\x04Z\x0b'
        b'__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<froz'
        b'en fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
